==> xlniuxdata-vipgame-1.0.0-20141225.035105-5-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerPay.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 客户付费查询实体类
 * @author lisu
 * 2013-02-21
 */
@Table(tableName = "customerpay", pkFieldName = "seqid", pkFieldAssign = false)
public class CustomerPay {
	private Long seqid;
	private String daytime;
	private Long payTotalAmt;
	private Integer vipGrade;
	@Column(columnName="daytime",isWhereColumn=true,operator=Operator.GE)
	private String fromdaytime;
	@Column(columnName="daytime",isWhereColumn=true,operator=Operator.LT)
	private String todaytime;
	@Column(columnName="vipGrade",isWhereColumn=true,operator=Operator.LE)
	private Integer customerVipGrade;
	
	public Integer getCustomerVipGrade() {
		return customerVipGrade;
	}
	public void setCustomerVipGrade(Integer customerVipGrade) {
		this.customerVipGrade = customerVipGrade;
	}
	
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public Long getPayTotalAmt() {
		return payTotalAmt;
	}
	public void setPayTotalAmt(Long payTotalAmt) {
		this.payTotalAmt = payTotalAmt;
	}
	public String getDaytime() {
		return daytime;
	}
	public void setDaytime(String daytime) {
		this.daytime = daytime;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public String getFromdaytime() {
		return fromdaytime;
	}
	public void setFromdaytime(String fromdaytime) {
		this.fromdaytime = fromdaytime;
	}
	public String getTodaytime() {
		return todaytime;
	}
	public void setTodaytime(String todaytime) {
		this.todaytime = todaytime;
	}
}

==> xlniuxdata-vipgame-1.0.33-20151109.062409-3-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerPay.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 客户付费查询实体类
 * @author lisu
 * 2013-02-21
 */
@Table(tableName = "customerpay", pkFieldName = "seqid", pkFieldAssign = false)
public class CustomerPay {
	private Long seqid;
	private String daytime;
	private Long payTotalAmt;
	private Integer vipGrade;
	@Column(columnName="daytime",isWhereColumn=true,operator=Operator.GE)
	private String fromdaytime;
	@Column(columnName="daytime",isWhereColumn=true,operator=Operator.LT)
	private String todaytime;
	@Column(columnName="vipGrade",isWhereColumn=true,operator=Operator.LE)
	private Integer customerVipGrade;
	private String gameId;
	
	
	
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public Integer getCustomerVipGrade() {
		return customerVipGrade;
	}
	public void setCustomerVipGrade(Integer customerVipGrade) {
		this.customerVipGrade = customerVipGrade;
	}
	
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public Long getPayTotalAmt() {
		return payTotalAmt;
	}
	public void setPayTotalAmt(Long payTotalAmt) {
		this.payTotalAmt = payTotalAmt;
	}
	public String getDaytime() {
		return daytime;
	}
	public void setDaytime(String daytime) {
		this.daytime = daytime;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public String getFromdaytime() {
		return fromdaytime;
	}
	public void setFromdaytime(String fromdaytime) {
		this.fromdaytime = fromdaytime;
	}
	public String getTodaytime() {
		return todaytime;
	}
	public void setTodaytime(String todaytime) {
		this.todaytime = todaytime;
	}
}
